/*
 * PokeFrog - A 'Pokemonized' verison of Frogger, the well-known Konami game.
 *
 * copyright (c) 2012 Fabien LOISON <http://www.flogisoft.com/>
 * 
 * this program is free software. it comes without any warranty, to
 * the extent permitted by applicable law. you can redistribute it
 * and/or modify it under the terms of the do what the fuck you want
 * to public license, version 2, as published by sam hocevar. see
 * http://sam.zoy.org/wtfpl/copying for more details. 
 */


/**
 * @module PokeFrog
 */


/**
 * Manages an enemy.
 *
 * @class Enemy
 * @constructor
 *
 * @param {wjs.Tileset} tileset The tileset that contain the enemies' sprites.
 * @param {String} tileId The identifier of the enemy tile.
 * @param {String} orientation The orientation (`"left"` or `"right"`).
 * @param {Number} speed The enemy's speed.
 * @param {Number} y The y position of the enemy.
 * @param {Array} hitbox The hitbox of the enemy (relative): `[x1, y1, x2, y2]`.
 */
function Enemy(tileset, tileId, orientation, speed, y, hitbox)
{
	this._tileset = tileset;
	this._tileId = tileId;
	this._orientation = orientation;
	this._speed = speed;
	this._hitbox = hitbox;

	if (this._orientation == 'left')
	{
		this._x = wjs.canvas.width;
	}
	else
	{
		this._x = -this._tileset._tiles[this._tileId].size[0];
	}
	this._y = y;

	this.outOfScreen = false
}

/**
 * Calculate the position of the enemy's hitbox on the canvas.
 *
 * @method getHitbox
 *
 * @return {Array} The hitbox: `[x1, y1, x2, y2]`.
 */
Enemy.prototype.getHitbox = function()
{
	return [
		this._x + this._hitbox[0],  // x1
		this._y + this._hitbox[1],  // y1
		this._x + this._hitbox[2],  // x2
		this._y + this._hitbox[3]]  // y2
}

/**
 * Update the enemy position.
 *
 * @method update
 */
Enemy.prototype.update = function()
{
	if (this._orientation == 'left')
	{
		this._x -= this._speed;
		if (this._x < -this._tileset._tiles[this._tileId].size[0])
		{
			this.outOfScreen = true;
		}
	}
	else
	{
		this._x += this._speed;
		if (this._x > wjs.canvas.width)
		{
			this.outOfScreen = true;
		}
	}
}

/**
 * Draw the enemy on the canvas.
 *
 * @method draw
 */
Enemy.prototype.draw = function()
{
	this._tileset.blit(this._tileId, this._x, this._y);

	// Debug: display the hitbox
	if (DEBUG)
	{
		var ctx = wjs.canvas.getContext('2d');
		var hitbox = this.getHitbox();
		ctx.lineWidth = 2;
		ctx.strokeStyle = '#f00';
		ctx.strokeRect(
				hitbox[0],  // x
				hitbox[1],  // y
				hitbox[2]-hitbox[0],  // width
				hitbox[3]-hitbox[1]); // height
	}
}


